%define module netaddr

Name:           python-%{module}
Version:        1.3.0
Release:        %mkrel 1
License:        BSD3c
Summary:        Pythonic manipulation of IPv4, IPv6, CIDR, EUI and MAC network addresses
Group:          Development/Python
Url:            https://github.com/drkjam/netaddr
Source:         https://pypi.python.org/packages/source/n/netaddr/%{module}-%{version}.tar.gz
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3-devel
BuildArch:      noarch

%description
A pure Python network address representation and manipulation library.

netaddr provides a Pythonic way of working with:
    - IPv4 and IPv6 addresses and subnets (including CIDR notation);
    - MAC (Media Access Control) addresses in multiple formats;
    - IEEE EUI-64, OUI and IAB identifiers;
    - a user friendly IP glob-style format.

Included are routines for:
    - generating, sorting and summarizing IP addresses;
    - converting IP addresses and ranges between various different formats;
    - performing set based operations on groups of IP addresses and subnets;
    - arbitrary IP address range calculations and conversions;
    - querying IEEE OUI and IAB organisational information;
    - querying of IP standards related data from key IANA data sources.

%package -n python3-%{module}
Summary:        Pythonic manipulation of IPv4, IPv6, CIDR, EUI and MAC network addresses
Group:          Development/Python
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)
%{?python_provide:%python_provide python3-%{module}}

%description -n python3-%{module}
A pure Python 3 network address representation and manipulation library.

netaddr provides a Pythonic way of working with:
    - IPv4 and IPv6 addresses and subnets (including CIDR notation);
    - MAC (Media Access Control) addresses in multiple formats;
    - IEEE EUI-64, OUI and IAB identifiers;
    - a user friendly IP glob-style format.

%prep
%setup -q -n %{module}-%{version}

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files netaddr

%files -n python3-%{module} -f %{pyproject_files}
%license COPYRIGHT.rst LICENSE.rst
%doc AUTHORS.rst CHANGELOG.rst README.rst
%{_bindir}/%{module}


%changelog
* Fri Jul 05 2024 papoteur <papoteur> 1.3.0-1.mga10
+ Revision: 2080044
- new version 1.3.0

* Mon Dec 18 2023 tv <tv> 0.9.0-2.mga10
+ Revision: 2018781
- No more need to call pathfix.py
+ papoteur <papoteur>
- rebuild for python 3.12
- new {paquet[1]}

* Wed Mar 23 2022 umeabot <umeabot> 0.8.0-4.mga9
+ Revision: 1823146
- Mageia 9 Mass Rebuild

* Sat Feb 19 2022 mrambo3501 <mrambo3501> 0.8.0-3.mga9
+ Revision: 1781487
- rebuild for python-3.10

* Sat Jun 26 2021 wally <wally> 0.8.0-2.mga9
+ Revision: 1732366
- Rebuild for python 3.9

* Thu Sep 03 2020 daviddavid <daviddavid> 0.8.0-1.mga8
+ Revision: 1621220
- new version: 0.8.0

* Wed Jun 24 2020 daviddavid <daviddavid> 0.7.20-1.mga8
+ Revision: 1599007
- new version: 0.7.20

* Sun Feb 16 2020 daviddavid <daviddavid> 0.7.19-3.mga8
+ Revision: 1531833
- fix python shebangs
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Wed Sep 11 2019 tv <tv> 0.7.19-2.mga8
+ Revision: 1439690
- rebuild for python-3.8
- drop python2 subpkg

* Fri Apr 19 2019 wally <wally> 0.7.19-1.mga7
+ Revision: 1393567
- new version 0.7.19

* Tue Jan 08 2019 tv <tv> 0.7.18-5.mga7
+ Revision: 1351627
- rebuild with python 3.7

* Thu Sep 20 2018 umeabot <umeabot> 0.7.18-4.mga7
+ Revision: 1289480
- Mageia 7 Mass Rebuild

* Sat Aug 05 2017 pterjan <pterjan> 0.7.18-3.mga7
+ Revision: 1135515
- Rebuild for python 3.6

* Fri Feb 19 2016 umeabot <umeabot> 0.7.18-2.mga6
+ Revision: 970858
- Mageia 6 Mass Rebuild

* Fri Oct 09 2015 daviddavid <daviddavid> 0.7.18-1.mga6
+ Revision: 888615
- new version: 0.7.18 + rebuild for python 3.5
- use new python macros
- update Source URL

* Wed Jan 21 2015 bcornec <bcornec> 0.7.13-1.mga5
+ Revision: 811680
- Update to upstream 0.7.13 to avoid security pbs mentioned in http://bugs.mageia.org/show_bug.cgi?id=15010

* Wed Oct 15 2014 umeabot <umeabot> 0.7.10-7.mga5
+ Revision: 740310
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.7.10-6.mga5
+ Revision: 729144
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 0.7.10-5.mga5
+ Revision: 688171
- Mageia 5 Mass Rebuild

* Sat May 31 2014 pterjan <pterjan> 0.7.10-4.mga5
+ Revision: 628839
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 0.7.10-3.mga4
+ Revision: 543830
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 0.7.10-2.mga4
+ Revision: 498961
- Rebuild to add different pythonegg provides for python 2 and 3

* Mon Oct 14 2013 philippem <philippem> 0.7.10-1.mga4
+ Revision: 497562
- Update to 0.7.10
- add Python 3

* Sun Jan 13 2013 umeabot <umeabot> 0.7.5-2.mga3
+ Revision: 379158
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Nov 03 2012 neoclust <neoclust> 0.7.5-1.mga3
+ Revision: 313246
- imported package python-netaddr


* Wed Jun 08 2011 Antoine Ginies <aginies@mandriva.com> 0.7.5-1mdv2011.0
+ Revision: 683258
- import python-netaddr


* Wed Jun 8 2011 Antoine Ginies <aginies@mandriva.com> 0.7.5
- first release for Mandriva 
